@@ -54,9 +54,7 @@
 #include "am_map.h"
 #include "lprintf.h"
 
-#ifdef _WIN32
-#include "WIN/win_fopen.h"
-#endif
+#include "m_io.h"
 
 static FILE *levelinfo;
 
@@ -677,7 +675,7 @@ static void gld_PrecalculateSector(int num)
             // the angle of the last candidate
             // e6y: for finding an angle between AB and BC vectors we should subtract
             // (BC - BA) == (BC - (180 - AB)) == (angle-(180-lineangle))
-            if (D_abs(angle-(180-lineangle))<D_abs(bestangle))
+            if (D_abs((int) angle - (180 - (int) lineangle))<D_abs((int) bestangle))
             {
               bestline=i;
               bestangle=angle-(180-lineangle);
@@ -864,7 +862,7 @@ static void gld_PreprocessSectors(void)
 #endif
 
 #ifdef PRBOOM_DEBUG
-  levelinfo=fopen("levelinfo.txt","a");
+  levelinfo=M_fopen("levelinfo.txt","a");
   if (levelinfo)
   {
     if (gamemode==commercial)
