@@ -80,8 +80,8 @@ typedef struct
 } channel_t;
 
 // the set of channels available
-static channel_t *channels;
-static degenmobj_t *sobjs;
+static channel_t channels[MAX_CHANNELS];
+static degenmobj_t sobjs[MAX_CHANNELS];
 
 // These are not used, but should be (menu).
 // Maximum volume of a sound effect.
@@ -145,14 +145,9 @@ void S_Init(int sfxVolume, int musicVolume)
 
     S_SetSfxVolume(sfxVolume);
 
-    // Allocating the internal channels for mixing
-    // (the maximum numer of sounds rendered
-    // simultaneously) within zone memory.
-    // CPhipps - calloc
-    channels =
-      (channel_t *) calloc(numChannels,sizeof(channel_t));
-    sobjs =
-      (degenmobj_t *) calloc(numChannels, sizeof(degenmobj_t));
+    // Reset channel memory
+    memset(channels, 0, sizeof(channels));
+    memset(sobjs, 0, sizeof(sobjs));
 
     // Note that sounds have not been cached (yet).
     for (i=1 ; i<NUMSFX ; i++)
